Extract substrings
Arguments
- string
Character vector of strings.
- start, end
Integer vectors specifying
startandendpositions (inclusive). Negative values count backwards from the right hand side; -1 refers to the last character.Instead of separate
startandendparameters you can alternatively provide a two-column matrix (i.e. fromstr_locate()); the first column will be used for the starting position and the second for the ending position.